@@ -1,3 +1,4 @@
+import asyncio
 
 class EventPipe:
     __instance = None
@@ -28,3 +29,4 @@ class EventPipe:
     async def __call_callback(self, event):
         if self.__callback is not None:
             await self.__callback(event)
+            await asyncio.sleep(0)
